==> haskell-hspec-megaparsec-2.2.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-K8PfoDuqWDNIcFHdgbNcQ0
key:                  hspec-megaparsec-2.2.1-K8PfoDuqWDNIcFHdgbNcQ0
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  d0d0670db079f3c9fa8ac3bc0923bb15
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-K8PfoDuqWDNIcFHdgbNcQ0
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    megaparsec-9.6.1-GGm6A6SUMwhJlD6BFvrrz

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.2.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-6gAtXiAWUz135WxaGazBTc
key:                  hspec-megaparsec-2.2.1-6gAtXiAWUz135WxaGazBTc
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  410799d73ab4c41a1407b8e75f90f108
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-6gAtXiAWUz135WxaGazBTc
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    megaparsec-9.6.1-8648askGGYL4sSdjKKAh81

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
